@@ -1,4 +1,6 @@
 from .rdjohns_pg import *
 from .Write_log import *
 from .date import *
-from .InsertComand import * 
\ No newline at end of file
+from .InsertComand import * 
+from .Datatable_Data import *
+from .Datatable_JS import *
\ No newline at end of file
